@@ -190,6 +190,8 @@ class SearchRunner(object):
             type=str, help='Entity to search for')
         o.add_argument('-d', '--data-dir', type=str, default='.', help='Files location')
 
+        self.o = o 
+
         if args is None:
             self.p = o.parse_args()
         else:
@@ -242,5 +244,8 @@ def main():
     try:
         r = SearchRunner()
         r.run()
+    except InvalidArgumentException as e:
+        print(f'Fatal error: {e}')
+        r.o.print_help()
     except Exception as e:
         print(f'Fatal error: {e}')
